package org.opengroup.osdu.notification.api;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;

import javax.servlet.http.HttpServletRequest;

import static org.junit.Assert.*;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class GlobalErrorControllerTest {

    @InjectMocks
    private GlobalErrorController globalErrorController;

    @Mock
    HttpServletRequest httpServletRequest;

    @Before
    public void setup(){
        MockitoAnnotations.initMocks(GlobalErrorControllerTest.this);
        when(httpServletRequest.getAttribute(eq("javax.servlet.error.exception"))).thenReturn(new Exception("sample exception"));
    }

    @Test
    public void handleErrorGetTest(){
        when(httpServletRequest.getAttribute(eq("javax.servlet.error.status_code"))).thenReturn(500);
       String expected = globalErrorController.handleErrorGet(httpServletRequest);
       assertEquals(expected,"{\"code\": 500, \"reason:\": \"Internal Server Error\" \"message\":\"An unknown error has occurred\" }");

    }

    @Test
    public void handleErrorPutTest(){
        when(httpServletRequest.getAttribute(eq("javax.servlet.error.status_code"))).thenReturn(404);
        String expected = globalErrorController.handleErrorPut(httpServletRequest);
        assertEquals(expected,"{\"code\": 404, \"reason:\": \"Not Found\" \"message\":\"sample exception\" }");

    }

    @Test
    public void handleErrorPatchTest(){
        when(httpServletRequest.getAttribute(eq("javax.servlet.error.status_code"))).thenReturn(500);
        String expected = globalErrorController.handleErrorPatch(httpServletRequest);
        assertEquals(expected,"{\"code\": 500, \"reason:\": \"Internal Server Error\" \"message\":\"An unknown error has occurred\" }");

    }

    @Test
    public void handleErrorDeleteTest(){
        when(httpServletRequest.getAttribute(eq("javax.servlet.error.status_code"))).thenReturn(500);
        String expected = globalErrorController.handleErrorDelete(httpServletRequest);
        assertEquals(expected,"{\"code\": 500, \"reason:\": \"Internal Server Error\" \"message\":\"An unknown error has occurred\" }");
    }

    @Test
    public void handleErrorPostTest(){
        when(httpServletRequest.getAttribute(eq("javax.servlet.error.status_code"))).thenReturn(500);
        String expected = globalErrorController.handleErrorPost(httpServletRequest);
        assertEquals(expected,"{\"code\": 500, \"reason:\": \"Internal Server Error\" \"message\":\"An unknown error has occurred\" }");
    }

    @Test
    public void getErrorPathTest() {
        assertEquals(globalErrorController.getErrorPath(),"/error");

    }

}