package org.opengroup.osdu.notification.di;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.mockito.Spy;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.cache.ICache;
import org.opengroup.osdu.core.common.cache.MultiTenantCache;
import org.opengroup.osdu.core.common.cache.RedisCache;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.core.common.model.tenant.TenantInfo;
import org.opengroup.osdu.core.common.multitenancy.PartitionTenantInfoFactory;
import org.opengroup.osdu.core.common.provider.interfaces.ITenantFactory;
import org.springframework.test.util.ReflectionTestUtils;

import static org.junit.Assert.*;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.anyString;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class SubscriptionCacheFactoryTest {

    SubscriptionCacheFactory subscriptionCacheFactory;

    @Mock
    private DpsHeaders headers;

    @Mock
    private PartitionTenantInfoFactory tenantFactory;

    @Mock
    private TenantInfo tenantInfo;


    @Before
    public void setup(){
        subscriptionCacheFactory = new SubscriptionCacheFactory(1234567,1000);
        MockitoAnnotations.initMocks(SubscriptionCacheFactoryTest.this);
        ReflectionTestUtils.setField(subscriptionCacheFactory,"headers",headers);
        ReflectionTestUtils.setField(subscriptionCacheFactory,"tenantFactory",tenantFactory);
        tenantInfo.setDataPartitionId("opendes");
        when(tenantFactory.getTenantInfo(any())).thenReturn(tenantInfo);
        when(headers.getPartitionIdWithFallbackToAccountId()).thenReturn("opendes");
        when(tenantInfo.getDataPartitionId()).thenReturn("opendes");
        subscriptionCacheFactory.put("testKey","testVal");

    }



    @Test
    public void getTest() {

        String actual = subscriptionCacheFactory.get("testKey");
        assertEquals("testVal",actual);
    }

    @Test
    public void deleteTest() {
        subscriptionCacheFactory.delete("testKey");
        assertNull(subscriptionCacheFactory.get("testKey"));

    }

    @Test
    public void clearAll() {
        subscriptionCacheFactory.clearAll();
        assertNull(subscriptionCacheFactory.get("testKey"));
    }
}